@@ -26,6 +26,7 @@ This file is part of Gnome Photo Printer.
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-job.h>
 #include <libgnomeprintui/gnome-print-dialog.h>
+#include <glib/gprintf.h>
 #include "gpp_print.h"
 #include "gpp_functions.h"
 #include "gpp_widget.h"
@@ -38,7 +39,7 @@ gpp_check_page_size ()
 {
 	gboolean ret = TRUE;
 	gint x, y;
-	
+
 	if (gpp_calculate_pics_on_page ()!=0)
 		return TRUE;
 
@@ -47,7 +48,7 @@ gpp_check_page_size ()
 
 	gpp_definition->layout_x = y;
 	gpp_definition->layout_y = x;
-	if (gpp_calculate_pics_on_page ()==0)	
+	if (gpp_calculate_pics_on_page ()==0)
 	{
 		gtk_widget_show_all (gpp_pagesize);
 		ret = FALSE;
@@ -65,7 +66,7 @@ gpp_set_layout ()
 {
 	gfloat width, height;
 
-	switch (gpp_definition->layout) 
+	switch (gpp_definition->layout)
         {
 	case LAYOUT_1:
 		gpp_definition->layout_x = gpp_calculate_size_metric_to_dpi (20);
@@ -112,7 +113,7 @@ gpp_set_layout ()
 
 	case LAYOUT_CUSTOM:
 	    // g_printf("Custom Units Seleciton: %s\n",gtk_combo_box_get_active_text(gpp_custom_units));
-		
+
 		switch (gtk_combo_box_get_active(gpp_custom_units))
 			{
 			case 0: /* cm */
@@ -120,33 +121,33 @@ gpp_set_layout ()
 				width = gtk_spin_button_get_value_as_float (gpp_custom_width);
 				height = gtk_spin_button_get_value_as_float (gpp_custom_height);
 				break;
-			
+
 			case 1: /* in */
 				/* Convert from inches to cm */
 				width = (gtk_spin_button_get_value_as_float (gpp_custom_width))*2.54;
 				// g_printf("Converted Width: %f\n",width);
-	
+
 				height = (gtk_spin_button_get_value_as_float (gpp_custom_height))*2.54;
 				// g_printf("Converted Height: %f\n",height);
 				break;
-		
+
 		}
-		
+
 		gpp_definition->layout_x = gpp_calculate_size_metric_to_dpi (width);
 		gpp_definition->layout_y = gpp_calculate_size_metric_to_dpi (height);
 		break;
 	}
 }
 
-/* 
+/*
 	Get the made Settings
 	return: true on success
 */
 gboolean
 gpp_get_settings_from_libgnomeprint ()
 {
-	gdouble width, height;
-	gboolean to_file;
+	gdouble width, height, ml, mr, mt, mb;
+	// gboolean to_file;
 
 	if (gnome_print_job_get_page_size (gpp_job, &width, &height) != TRUE)
 	{
@@ -154,9 +155,13 @@ gpp_get_settings_from_libgnomeprint ()
 		return FALSE;
 	}
 
-	gpp_definition->paper_size_x = width;
-	gpp_definition->paper_size_y = height;
+	gnome_print_config_get_length (gpp_config, GNOME_PRINT_KEY_PAGE_MARGIN_LEFT, &ml, NULL);
+	gnome_print_config_get_length (gpp_config, GNOME_PRINT_KEY_PAGE_MARGIN_RIGHT, &mr, NULL);
+	gnome_print_config_get_length (gpp_config, GNOME_PRINT_KEY_PAGE_MARGIN_TOP, &mt, NULL);
+	gnome_print_config_get_length (gpp_config, GNOME_PRINT_KEY_PAGE_MARGIN_BOTTOM, &mb, NULL);
 
+	gpp_definition->paper_size_x = width - mr - ml;
+	gpp_definition->paper_size_y = height - mb - mt;
 
 	/* This truely needs to be fixed!!! Its a bug inside libgnomeprint!!!
 	 * if (gnome_print_config_get_boolean
@@ -171,7 +176,7 @@ gpp_get_settings_from_libgnomeprint ()
 	 * }
 	 */
 
-	/* Needs to be fixed when libgnomeprintui gets fixed! 
+	/* Needs to be fixed when libgnomeprintui gets fixed!
 	 * if (gnome_print_config_get
 	 * (gpp_config, "Settings.Transport.Backend.FileName") == NULL)
 	 * {
@@ -196,8 +201,8 @@ gpp_get_settings_from_libgnomeprint ()
 	return TRUE;
 }
 
-/* 
-	Show the settings 
+/*
+	Show the settings
 	return: is TRUE on success
 */
 gboolean
@@ -205,7 +210,6 @@ gpp_show_settings_from_libgnomeprint ()
 {
 	GtkTreeIter iter;
 	GtkTreeModel *tree;
-	gint i;
 	gboolean valid;
 
 	g_printf ("Print to file: %d\n", gpp_definition->to_file);
@@ -241,9 +245,9 @@ gpp_show_settings_from_libgnomeprint ()
 	return TRUE;
 }
 
-/* 
-	Calculate the pictures sizes (in metric) 
-	size: is in cm 
+/*
+	Calculate the pictures sizes (in metric)
+	size: is in cm
 	return: is in dots
 */
 gdouble
@@ -314,7 +318,7 @@ gpp_calculate_number_of_sites ()
 	return sites;
 }
 
-/* 
+/*
 	Calculates the number of pictures that fit on one page.
 	return: number of pictures
 */
@@ -353,7 +357,7 @@ gpp_calculate_space_between_pics (gdouble page, gdouble pic)
 	return spaces;
 }
 
-/* 
+/*
 	Rotates one picture at 90 degree
 	input: pixbuf
 	return: pixbuf
